BernoulliDistribution class

The Bernoulli distribution is a discrete probability distribution which takes value 1 with probability p and value 0 with probability q = 1 − p.

See https://en.wikipedia.org/wiki/Bernoulli_distribution.

Inheritance

Constructors

BernoulliDistribution(double p)
A bernoulli distribution with parameter p.
const

Properties

defaultToStringPrinter → ObjectPrinter
Override to configure the empty ObjectPrinter.
no setterinherited
hashCode → int
The hash code for this object.
no setteroverride
kurtosisExcess → double
Returns the excess kurtosis.
no setteroverride
lowerBound → int
Returns the lower boundary of the distribution.
no setteroverride
mean → double
Returns the mean value of the distribution.
no setteroverride
median → double
Returns the median value of the distribution.
no setteroverride
mode → double
Returns the mode, a value that appears most commonly in the set of values.
no setteroverride
p → double
Success probability for each trial (0..1).
final
q → double
Failure probability for each trial (0..1).
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
skewness → double
Returns the skewness of the distribution.
no setteroverride
standardDeviation → double
Returns the expected standard deviation.
no setterinherited
toStringPrinter → ObjectPrinter
Override and call super to add values to the ObjectPrinter.
no setter
upperBound → int
Returns the upper boundary of the distribution.
no setteroverride
variance → double
Returns the expected variance.
no setteroverride

Methods

cumulativeProbability(int k) → double
The Cumulative Distribution Function (CDF).
override
inverseCumulativeProbability(num p) → int
The Inverse Cumulative Distribution Function (PPT), or quantile function.
inherited
inverseSurvival(num p) → int
Inverse Survival Function (ISF).
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
probability(int k) → double
The Probability Density/Mass Function (PDF/PMF).
override
sample({Random? random}) → int
Returns a single sample of a random value within the distribution.
override
samples({Random? random}) → Iterable<int>
Returns an infinite source of random samples within the distribution.
inherited
survival(int x) → double
The Survival Function (SF), or Complementary cumulative distribution function.
inherited
toString() → String
Standard Object.toString implementation. Do not override, instead implement toStringPrinter to customize.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override