BigIntEquality class

Inheritance

Constructors

BigIntEquality()
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

hash(BigInt a) → int
Return the hash code of a.
inherited
isClose(BigInt a, BigInt b, double epsilon) → bool
Returns true, if a and b are within range of epsilon.
override
isEqual(BigInt a, BigInt b) → bool
Returns true, if a and b are the same.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited