IntegerField class

Inheritance

Constructors

IntegerField()
const

Properties

additiveIdentity → int
The additive neutral element.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
infinity → int
Positive infinity.
no setterinherited
multiplicativeIdentity → int
The multiplicative neutral element.
no setteroverride
nan → int
Not a number.
no setterinherited
negativeInfinity → int
Negative infinity.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

add(int a, int b) → int
Computes the addition: a + b.
override
div(int a, int b) → int
Computes the division: a / b.
override
division(int a, int b) → int
Computes a truncating division: a ~/ b.
override
gcd(int a, int b) → int
Computes the greatest common divisor: gcd(a, b).
override
inv(int a) → int
Computes the multiplicative inverse: 1 / a.
override
mod(int a, int b) → int
Computes the remainder of the Euclidean division a % b.
override
modInverse(int base, int modulus) → int
Computes the modular multiplicative inverse of base modulo modulus.
override
modPow(int base, int exponent, int modulus) → int
Computes base to the power of exponent modulo modulus.
override
mul(int a, int b) → int
Computes the multiplication: a * b.
override
neg(int a) → int
Computes the additive inverse: -a.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pow(int base, int exponent) → int
Computes base to the power of exponent.
override
remainder(int a, int b) → int
Computes the remainder of the truncating division.
override
scale(int a, num f) → int
Computes the multiplicative scaling: a * f.
override
sub(int a, int b) → int
Computes the subtraction: a - b.
override
toString() → String
A string representation of this object.
inherited
unsupportedOperation(String operation) → int
Thrown when an operation is not supported.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited