TestingMatrixExtension<T> extension

on

Properties

isDiagonal → bool

Available on Matrix<T>, provided by the TestingMatrixExtension extension

Tests if this Matrix is a diagonal matrix, with non-zero values only on the diagonal.
no setter
isLowerTriangular → bool

Available on Matrix<T>, provided by the TestingMatrixExtension extension

Tests if this Matrix is a lower triangular matrix, with non-zero values only in the lower-triangle of the matrix.
no setter
isSquare → bool

Available on Matrix<T>, provided by the TestingMatrixExtension extension

Tests if this Matrix is square.
no setter
isSymmetric → bool

Available on Matrix<T>, provided by the TestingMatrixExtension extension

Tests if this Matrix is symmetric (equal to its transposed form).
no setter
isUpperTriangular → bool

Available on Matrix<T>, provided by the TestingMatrixExtension extension

Tests if this Matrix is a upper triangular matrix, with non-zero values only in the upper-triangle of the matrix.
no setter