WeibullDistribution class

Inheritance

Constructors

WeibullDistribution(double scale, double shape)
A weibull distribution with parameters scale λ and shape k.
const

Properties

defaultToStringPrinter → ObjectPrinter
Override to configure the empty ObjectPrinter.
no setterinherited
hashCode → int
The hash code for this object.
no setteroverride
kurtosisExcess → double
Returns the excess kurtosis.
no setteroverride
lowerBound → double
Returns the lower boundary of the distribution.
no setteroverride
mean → double
Returns the mean value of the distribution.
no setteroverride
median → double
Returns the median value of the distribution.
no setteroverride
mode → double
Returns the mode, a value that appears most commonly in the set of values.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scale → double
The scale parameter λ.
final
shape → double
The shape parameter k.
final
skewness → double
Returns the skewness of the distribution.
no setteroverride
standardDeviation → double
Returns the expected standard deviation.
no setterinherited
toStringPrinter → ObjectPrinter
Override and call super to add values to the ObjectPrinter.
no setter
upperBound → double
Returns the upper boundary of the distribution.
no setterinherited
variance → double
Returns the expected variance.
no setteroverride

Methods

cumulativeProbability(double x) → double
The Cumulative Distribution Function (CDF).
override
inverseCumulativeProbability(num p) → double
The Inverse Cumulative Distribution Function (PPT), or quantile function.
override
inverseSurvival(num p) → double
Inverse Survival Function (ISF).
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
probability(double x) → double
The Probability Density/Mass Function (PDF/PMF).
override
sample({Random? random}) → double
Returns a single sample of a random value within the distribution.
override
samples({Random? random}) → Iterable<double>
Returns an infinite source of random samples within the distribution.
inherited
survival(double x) → double
The Survival Function (SF), or Complementary cumulative distribution function.
inherited
toString() → String
Standard Object.toString implementation. Do not override, instead implement toStringPrinter to customize.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override